summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp')
-rw-r--r--kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp b/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
index a060b23a..39fbfdda 100644
--- a/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
+++ b/kopete/protocols/jabber/libiris/cutestuff/network/ndns.cpp
@@ -21,7 +21,7 @@
//! \class NDns ndns.h
//! \brief Simple DNS resolution using native system calls
//!
-//! This class is to be used when Qt's TQDns is not good enough. Because QDns
+//! This class is to be used when TQt's TQDns is not good enough. Because TQDns
//! does not use threads, it cannot make a system call asyncronously. Thus,
//! TQDns tries to imitate the behavior of each platform's native behavior, and
//! generally falls short.
@@ -69,7 +69,7 @@
// CS_NAMESPACE_BEGIN
//! \if _hide_doc_
-class NDnsWorkerEvent : public QCustomEvent
+class NDnsWorkerEvent : public TQCustomEvent
{
public:
enum Type { WorkerEvent = TQEvent::User + 100 };
@@ -78,7 +78,7 @@ public:
NDnsWorker *worker;
};
-class NDnsWorker : public QThread
+class NDnsWorker : public TQThread
{
public:
NDnsWorker(TQObject *, const TQCString &);
@@ -116,7 +116,7 @@ public:
class NDnsManager::Private
{
public:
- Item *find(const NDns *n)
+ Item *tqfind(const NDns *n)
{
TQPtrListIterator<Item> it(list);
for(Item *i; (i = it.current()); ++it) {
@@ -126,7 +126,7 @@ public:
return 0;
}
- Item *find(const NDnsWorker *w)
+ Item *tqfind(const NDnsWorker *w)
{
TQPtrListIterator<Item> it(list);
for(Item *i; (i = it.current()); ++it) {
@@ -157,7 +157,7 @@ NDnsManager::NDnsManager()
d = new Private;
d->list.setAutoDelete(true);
- connect(qApp, TQT_SIGNAL(aboutToQuit()), TQT_SLOT(app_aboutToQuit()));
+ connect(tqApp, TQT_SIGNAL(aboutToQuit()), TQT_SLOT(app_aboutToQuit()));
}
NDnsManager::~NDnsManager()
@@ -184,7 +184,7 @@ void NDnsManager::resolve(NDns *self, const TQString &name)
void NDnsManager::stop(NDns *self)
{
- Item *i = d->find(self);
+ Item *i = d->tqfind(self);
if(!i)
return;
// disassociate
@@ -200,7 +200,7 @@ void NDnsManager::stop(NDns *self)
bool NDnsManager::isBusy(const NDns *self) const
{
- Item *i = d->find(self);
+ Item *i = d->tqfind(self);
return (i ? true: false);
}
@@ -210,7 +210,7 @@ bool NDnsManager::event(TQEvent *e)
NDnsWorkerEvent *we = static_cast<NDnsWorkerEvent*>(e);
we->worker->wait(); // ensure that the thread is terminated
- Item *i = d->find(we->worker);
+ Item *i = d->tqfind(we->worker);
if(!i) {
// should NOT happen
return true;
@@ -242,7 +242,7 @@ void NDnsManager::tryDestroy()
void NDnsManager::app_aboutToQuit()
{
while(man) {
- TQEventLoop *e = qApp->eventLoop();
+ TQEventLoop *e = tqApp->eventLoop();
e->processEvents(TQEventLoop::WaitForMore);
}
}
@@ -256,9 +256,9 @@ void NDnsManager::app_aboutToQuit()
//! This signal is emitted when the DNS resolution succeeds or fails.
//!
-//! Constructs an NDns object with parent \a parent.
-NDns::NDns(TQObject *parent)
-:TQObject(parent)
+//! Constructs an NDns object with tqparent \a tqparent.
+NDns::NDns(TQObject *tqparent)
+:TQObject(tqparent)
{
}